package com.uas.app.city.account;

import com.uas.account.web.AccountConfigurer;
import com.uas.sso.web.SSOConfigurer;
import java.io.IOException;
import java.io.InputStream;
import java.util.Properties;
import java.util.logging.Logger;
import org.springframework.boot.Banner.Mode;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.boot.builder.SpringApplicationBuilder;
import org.springframework.context.ApplicationContext;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Profile;

/**
 * The application class for account service is designed for the city service.
 *
 * @author huxz
 */
@SpringBootApplication
public class AccountApplication {

    private static final Logger logger = Logger.getLogger(SSOConfigurer.class.getName());

    @Bean(name = "accountConfigurer")
    @Profile(value = {"dev"})
    public AccountConfigurer devAccountConfigurer(ApplicationContext applicationContext) {

        AccountConfigurer configurer = new AccountConfigurer();
        configurer.setConfigPath("account-dev.properties");

        // 解决Spring Boot应用不支持Resource.getFile方式读取配置文件的问题
        Properties prop = getProperties(applicationContext, "classpath:account-dev.properties");

        if (prop != null) {
            configurer.initProperties(prop);
        } else {
            logger.severe("Initializing is not available AccountConfigLocation on the classpath");
        }

        return configurer;
    }

    @Bean(name = "accountConfigurer")
    @Profile(value = {"test", "prod"})
    public AccountConfigurer prodAccountConfigurer(ApplicationContext applicationContext) {

        AccountConfigurer configurer = new AccountConfigurer();
        configurer.setConfigPath("account-prod.properties");

        // 解决Spring Boot应用不支持Resource.getFile方式读取配置文件的问题
        Properties prop = getProperties(applicationContext, "classpath:account-prod.properties");

        if (prop != null) {
            configurer.initProperties(prop);
        } else {
            logger.severe("Initializing is not available AccountConfigLocation on the classpath");
        }

        return configurer;
    }

    private Properties getProperties(ApplicationContext applicationContext, String location) {
        Properties prop = null;
        try (InputStream stream = applicationContext.getResource(location).getInputStream()) {
            prop = new Properties();
            prop.load(stream);
        } catch (IOException e) {
            e.printStackTrace();
            logger.severe(" account read config file error. \n" + e.toString());
        }
        return prop;
    }

    public static void main(String[] args) {
        new SpringApplicationBuilder(AccountApplication.class)
                .bannerMode(Mode.OFF)
                .web(true)
                .run(args);
    }
}
