package com.uas.app.city.account.config;

import com.uas.app.city.account.config.interceptors.SsoInterceptor;
import com.uas.app.city.account.service.LocalUserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Configuration;
import org.springframework.web.servlet.config.annotation.InterceptorRegistry;
import org.springframework.web.servlet.config.annotation.ViewControllerRegistry;
import org.springframework.web.servlet.config.annotation.WebMvcConfigurerAdapter;

/**
 * An implementation of {@link WebMvcConfigurerAdapter} designed to config
 * spring web mvc.
 *
 * @author huxz
 */
@Configuration
public class WebMvcConfiguration extends WebMvcConfigurerAdapter {

    private final LocalUserService userService;

    @Autowired
    public WebMvcConfiguration(LocalUserService userService) {
        this.userService = userService;
    }

    @Override
    public void addInterceptors(InterceptorRegistry registry) {
        registry.addInterceptor(new SsoInterceptor(this.userService))
                .addPathPatterns("/**")
                .excludePathPatterns("/")
                .excludePathPatterns("/index.html")
                .excludePathPatterns("/error")
                .excludePathPatterns("/login/**", "/logout/**", "/register/**")
                .excludePathPatterns("/public/**")
                .excludePathPatterns("/sync/**");
    }

    @Override
    public void addViewControllers(ViewControllerRegistry registry) {
        registry.addViewController("/api").setViewName("/api.html");
        registry.addViewController("/login/proxy").setViewName("/proxy-login.html");
        registry.addViewController("/logout/proxy").setViewName("/proxy-logout.html");
        registry.addViewController("/admin").setViewName("/admin.html");
    }
}
