package com.uas.app.city.account.config;

import com.uas.app.city.account.config.zuul.CustomRouteLocator;
import com.uas.app.city.account.config.zuul.filters.AccessPreFilter;
import com.uas.app.city.account.third.service.AccessTokenService;
import org.apache.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.web.ServerProperties;
import org.springframework.cloud.netflix.zuul.EnableZuulProxy;
import org.springframework.cloud.netflix.zuul.filters.ZuulProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.jdbc.core.JdbcTemplate;

/**
 * A Configuration class for Zuul configuration and extension.
 *
 * @author huxz
 */
@EnableZuulProxy
@Configuration
public class ZuulConfiguration {

    private static final Logger logger = Logger.getLogger(ZuulConfiguration.class);

    private final ZuulProperties zuulProperties;

    private final ServerProperties serverProperties;

    private final JdbcTemplate jdbcTemplate;

    private final AccessTokenService accessTokenService;

    @Autowired
    public ZuulConfiguration(ZuulProperties zuulProperties, ServerProperties serverProperties,
            JdbcTemplate jdbcTemplate,
            AccessTokenService accessTokenService) {
        this.zuulProperties = zuulProperties;
        this.serverProperties = serverProperties;
        this.jdbcTemplate = jdbcTemplate;
        this.accessTokenService = accessTokenService;
    }

    @Bean
    public CustomRouteLocator routeLocator() {
        if (logger.isDebugEnabled()) {
            logger.debug("Custom route locator is used");
        }

        CustomRouteLocator routeLocator = new CustomRouteLocator(
                this.serverProperties.getServletPrefix(), this.zuulProperties);
        routeLocator.setJdbcTemplate(jdbcTemplate);
        return routeLocator;
    }

    @Bean
    public AccessPreFilter accessPreFilter() {
        return new AccessPreFilter(accessTokenService);
    }
}
