package com.uas.app.city.account.model;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import java.io.Serializable;
import java.util.Date;
import java.util.HashSet;
import java.util.Set;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.Index;
import javax.persistence.ManyToMany;
import javax.persistence.Table;
import org.hibernate.validator.constraints.NotEmpty;
import org.hibernate.validator.constraints.URL;

/**
 * Store city info about this app.
 *
 * @author huxz
 */
@Entity
@Table(name = "city", indexes = {@Index(columnList = "city_domain", unique = true)})
@JsonInclude(Include.NON_EMPTY)
@JsonIgnoreProperties({"companies", "userSet"})
public class City implements Serializable {

    private static final long serialVersionUID = -1057149980036522197L;

    @Id
    @GeneratedValue
    @Column(name = "city_id")
    private Long id;

    @NotEmpty(message = "City name can't be empty")
    @Column(name = "city_name")
    private String name;

    @Column(name = "city_short_name")
    private String shortName;

    @NotEmpty(message = "City domain can't be empty")
    @Column(name = "city_domain")
    private String domain;

    /**
     * 注册时间.
     */
    @Column(name = "reg_date")
    private Date regDate;

    /**
     * 营业执照号.
     */
    @NotEmpty(message = "City business code can't be empty")
    @Column(name = "business_code")
    private String businessCode;

    /**
     * 所在省份.
     */
    @NotEmpty(message = "City province can't be empty")
    @Column(name = "city_province")
    private String province;

    /**
     * 所在市.
     */
    @NotEmpty(message = "City town can't be empty")
    @Column(name = "city_town")
    private String city;

    /**
     * 详细地址.
     */
    @NotEmpty(message = "City detail address can't be empty")
    @Column(name = "city_detail_address")
    private String address;

    @Column(name = "city_longitude")
    private Float longitude;

    @Column(name = "city_latitude")
    private Float latitude;

    @NotEmpty(message = "City telephone can't be empty")
    @Column(name = "telephone")
    private String telephone;

    /**
     * 运营系统地址.
     */
    @NotEmpty(message = "City admin site can't be empty")
    @URL(message = "City admin site url is illegal")
    @Column(name = "admin_site")
    private String adminSite;

    /**
     * 门户网站地址.
     */
    @NotEmpty(message = "City portal site can't be empty")
    @URL(message = "City portal site url is illegal")
    @Column(name = "portal_site")
    private String portalSite;

    @ManyToMany(mappedBy = "cities")
    private Set<Company> companies = new HashSet<>();

    @ManyToMany(mappedBy = "cities")
    private Set<LocalUser> userSet = new HashSet<>();

    public City() {
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getShortName() {
        return shortName;
    }

    public void setShortName(String shortName) {
        this.shortName = shortName;
    }

    public String getDomain() {
        return domain;
    }

    public void setDomain(String domain) {
        this.domain = domain;
    }

    public Date getRegDate() {
        return regDate;
    }

    public void setRegDate(Date regDate) {
        this.regDate = regDate;
    }

    public String getBusinessCode() {
        return businessCode;
    }

    public void setBusinessCode(String businessCode) {
        this.businessCode = businessCode;
    }

    public String getProvince() {
        return province;
    }

    public void setProvince(String province) {
        this.province = province;
    }

    public String getCity() {
        return city;
    }

    public void setCity(String city) {
        this.city = city;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public Float getLongitude() {
        return longitude;
    }

    public void setLongitude(Float longitude) {
        this.longitude = longitude;
    }

    public Float getLatitude() {
        return latitude;
    }

    public void setLatitude(Float latitude) {
        this.latitude = latitude;
    }

    public String getTelephone() {
        return telephone;
    }

    public void setTelephone(String telephone) {
        this.telephone = telephone;
    }

    public String getAdminSite() {
        return adminSite;
    }

    public void setAdminSite(String adminSite) {
        this.adminSite = adminSite;
    }

    public String getPortalSite() {
        return portalSite;
    }

    public void setPortalSite(String portalSite) {
        this.portalSite = portalSite;
    }

    public Set<Company> getCompanies() {
        return companies;
    }

    public void setCompanies(Set<Company> companies) {
        this.companies = companies;
    }

    public Set<LocalUser> getUserSet() {
        return userSet;
    }

    public void setUserSet(Set<LocalUser> userSet) {
        this.userSet = userSet;
    }
}
