package com.uas.app.city.account.model;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;

import javax.persistence.*;
import java.io.Serializable;
import java.util.Date;
import java.util.HashSet;
import java.util.Set;

/**
 * Store settled company info about this app.
 *
 * @author huxz
 */
@Entity
@Table(name = "company", indexes = {@Index(columnList = "business_code", unique = true)})
@JsonInclude(Include.NON_EMPTY)
@JsonIgnoreProperties("users")
public class Company implements Serializable {

    private static final long serialVersionUID = 8828090286791125952L;

    @Id
    @GeneratedValue
    @Column(name = "id")
    private Long id;

    @Column(name = "en_name")
    private String name;

    @Column(name = "en_short_name")
    private String shortName;

    @Column(name = "reg_date")
    private Date regDate;

    @Column(name = "business_code")
    private String businessCode;

    @Column(name = "telephone")
    private String telephone;

    @Column(name = "spaceUU", unique = true)
    private Long spaceUU;

    @ManyToMany(mappedBy = "enterprises", fetch = FetchType.EAGER)
    private Set<LocalUser> users = new HashSet<>();

    @ManyToMany(fetch = FetchType.EAGER)
    @JoinTable(name = "map_city_company",
            joinColumns = {@JoinColumn(name = "company_id", referencedColumnName = "id")},
            inverseJoinColumns = {@JoinColumn(name = "city_id", referencedColumnName = "city_id")})
    private Set<City> cities = new HashSet<>();

    public Company() {
    }

    public Long getSpaceUU() {
        return spaceUU;
    }

    public void setSpaceUU(Long spaceUU) {
        this.spaceUU = spaceUU;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getShortName() {
        return shortName;
    }

    public void setShortName(String shortName) {
        this.shortName = shortName;
    }

    public Date getRegDate() {
        return regDate;
    }

    public void setRegDate(Date regDate) {
        this.regDate = regDate;
    }

    public String getBusinessCode() {
        return businessCode;
    }

    public void setBusinessCode(String businessCode) {
        this.businessCode = businessCode;
    }

    public String getTelephone() {
        return telephone;
    }

    public void setTelephone(String telephone) {
        this.telephone = telephone;
    }

    public Set<LocalUser> getUsers() {
        return users;
    }

    public void setUsers(Set<LocalUser> users) {
        this.users = users;
    }

    public Set<City> getCities() {
        return cities;
    }

    public void setCities(Set<City> cities) {
        this.cities = cities;
    }

}
