package com.uas.app.city.account.model;

import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;

import javax.persistence.*;
import java.io.Serializable;
import java.util.HashSet;
import java.util.Set;

/**
 * Store local user extension info about this app.
 *
 * @author huxz
 */
@Entity
@Table(name = "user_info")
@JsonInclude(Include.NON_EMPTY)
public class LocalUser implements BaseUser, Serializable {

    private static final long serialVersionUID = 7388221952816044239L;

    @Id
    @GeneratedValue
    @Column(name = "id")
    private Long id;

    @Column(name = "user_uu", unique = true)
    private Long userUu;

    /**
     * 微信号
     */
    @Column(name = "wx_open_id")
    private String wxOpenId;

    @Transient
    private UserView user;

    @ManyToMany(fetch = FetchType.EAGER)
    @JoinTable(name = "map_company_user",
            joinColumns = {@JoinColumn(name = "user_id", referencedColumnName = "id")},
            inverseJoinColumns = {@JoinColumn(name = "company_id", referencedColumnName = "id")})
    private Set<Company> enterprises = new HashSet<>();

    @Transient
    private Company enterprise;

    @ManyToMany(fetch = FetchType.EAGER)
    @JoinTable(name = "map_city_user",
            joinColumns = {@JoinColumn(name = "user_id", referencedColumnName = "id")},
            inverseJoinColumns = {@JoinColumn(name = "city_id", referencedColumnName = "city_id")})
    private Set<City> cities = new HashSet<>();

    @Transient
    private City currentCity;

    public LocalUser() {
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getUserUu() {
        return userUu;
    }

    public void setUserUu(Long userUu) {
        this.userUu = userUu;
    }

    public void setUser(UserView user) {
        this.user = user != null ? user : new UserView();
    }

    public UserView getUser() {
        return user;
    }

    @Override
    public String getName() {
        return this.user.getUsername();
    }

    @Override
    public String getMobile() {
        return this.user.getMobile();
    }

    @Override
    public String getEmail() {
        return this.user.getEmail();
    }

    public String getWxOpenId() {
        return wxOpenId;
    }

    public void setWxOpenId(String wxOpenId) {
        this.wxOpenId = wxOpenId;
    }

    public Set<Company> getEnterprises() {
        return enterprises;
    }

    public void setEnterprises(Set<Company> enterprises) {
        this.enterprises = enterprises;
    }

    public Company getEnterprise() {
        return enterprise;
    }

    public void setEnterprise(Company enterprise) {
        this.enterprise = enterprise;
    }

    public Set<City> getCities() {
        return cities;
    }

    public void setCities(Set<City> cities) {
        this.cities = cities;
    }

    public City getCurrentCity() {
        return currentCity;
    }

    public void setCurrentCity(City currentCity) {
        this.currentCity = currentCity;
    }

}
