package com.uas.app.city.account.service;

import com.uas.app.city.account.model.City;
import java.util.List;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;

/**
 * An abstract class of city info.
 *
 * @author huxz
 */
public interface CityService {

    /**
     * Insert one city info when admin adds.
     *
     * @param city  city info to be inserted
     * @return saved city
     */
    City insertCityInfoWhenAdminAdds(City city);

    /**
     * Paging city info according to conditions.
     *
     * @param pageable  page params
     * @return  Page
     */
    Page<City> pageCityOnConditions(Pageable pageable);

    /**
     * Update one city info when admin edits.
     *
     * @param city  city info to be updated
     * @return saved city
     */
    City updateCityInfoWhenAdminEdit(City city);

    /**
     * Delete one city info when admin operates.
     *
     * @param cityId  city id
     * @return deleted city
     */
    City deleteCityInfoByAdmin(Long cityId);

    /**
     * Find city list of current user.
     *
     * @return  city list
     */
    List<City> findCityListOfOneUser();
}
