package com.uas.app.city.account.service.impl;

import com.uas.app.city.account.dao.CompanyDao;
import com.uas.app.city.account.model.Company;
import com.uas.app.city.account.service.CompanyService;
import com.uas.sso.entity.UserSpaceView;
import com.uas.sso.util.AccountUtils;
import org.apache.commons.lang3.StringUtils;
import org.apache.commons.lang3.Validate;
import org.apache.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * An implementation class for {@code CityService}.
 *
 * @author huxz
 */
@Service
public class CompanyServiceImpl implements CompanyService {

    @Autowired
    private CompanyDao companyDao;

    private static final Logger logger = Logger.getLogger(CompanyServiceImpl.class);

    @Override
    public Company findUserSpaceByBusinessCode(String businessCode) {
        Validate.notBlank(businessCode, "Business Code can't be empty");

        try {
            UserSpaceView userSpaceView = AccountUtils.findByBusinessCode(businessCode);
            if (userSpaceView != null && StringUtils.isNotEmpty(userSpaceView.getBusinessCode())) {
                Company company = new Company();
                company.setBusinessCode(userSpaceView.getBusinessCode());
                company.setName(userSpaceView.getSpaceName());
                company.setShortName(userSpaceView.getSpaceName());
//                新版账户中心没有企业注册时间
//                company.setRegDate(new Date(userSpaceView.getRegisterDate()));
                company.setTelephone(userSpaceView.getTelephone());
                return company;
            } else {
                // 检查注册产城的企业是否在平台注册，如果没有通知其在平台上进行注册
                throw new IllegalStateException(String.format("Company %s hasn't registered",
                        businessCode));
            }
        } catch (Exception e) {
            logger.error("Network exception", e);
        }
        return null;
    }

    @Override
    public Company save(Company company) {
        return companyDao.save(company);
    }

    @Override
    public Company getCompanyBySpaceUU(Long spaceUU) {
        Company company = companyDao.getCompanyBySpaceUU(spaceUU);
        return company;
    }
}
