package com.uas.app.city.account.third.api;

import com.uas.app.city.account.third.model.AccessToken;
import com.uas.app.city.account.third.service.AccessTokenService;
import javax.servlet.http.HttpServletRequest;
import org.apache.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

/**
 * 对可信任第三方公开的资料查询接口
 * <p>
 * 例如：客户的UAS系统、管理系统
 * </p>
 * 
 * @author yingp
 * 
 */
@SuppressWarnings("deprecation")
@Controller
@RequestMapping("/public/queriable")
public class PublicQueryController {

    private static final Logger logger = Logger.getLogger(PublicQueryController.class);

	private final AccessTokenService accessTokenService;

	@Autowired
	public PublicQueryController(
			AccessTokenService accessTokenService) {
		this.accessTokenService = accessTokenService;
	}

	/**
	 * 验证临时token的接口
	 * 
	 * <pre>
	 * 临时token阅后即焚
	 * </pre>
	 * 
	 * @author yingp
	 * 
	 */
	@RequestMapping(value = "/token", method = RequestMethod.GET)
	@ResponseBody
	public ResponseEntity<ModelMap> getUserByToken(HttpServletRequest request, String access_token) {
	    if (logger.isDebugEnabled()) {
	        logger.debug("Incoming request: " + request.getRemoteAddr());
        }

		ModelMap data = new ModelMap();
		AccessToken token = accessTokenService.findOne(access_token);
		if (token == null) {
			data.put("error", "验证信息错误或已过期");
			return new ResponseEntity<>(data, HttpStatus.NOT_FOUND);
		}
		data.put("user", token.getUser());
		data.put("userUU", token.getUserUU());
		data.put("enUU", token.getEnUU());
		data.put("bind", token.getBind());
		accessTokenService.delete(token.getId());
		return new ResponseEntity<>(data, HttpStatus.OK);
	}
}
