package com.uas.app.city.account.third.dao.impl;

import com.uas.app.city.account.third.dao.AccessTokenDao;
import com.uas.app.city.account.third.model.AccessToken;
import com.uas.app.city.account.util.FlexJsonUtils;
import java.io.Serializable;
import org.apache.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.dao.DataAccessException;
import org.springframework.data.redis.connection.RedisConnection;
import org.springframework.data.redis.core.RedisCallback;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Repository;

@Repository
public class AccessTokenDaoImpl implements AccessTokenDao {

    private static final Logger logger = Logger.getLogger(AccessTokenDaoImpl.class);

	private final RedisTemplate<Serializable, Serializable> redisTemplate;

	@Autowired
	public AccessTokenDaoImpl(
			RedisTemplate redisTemplate) {
		this.redisTemplate = redisTemplate;
	}

	@Override
	public void save(final AccessToken token) {
	    if (logger.isDebugEnabled()) {
	        logger.debug("Access token: " + token.getId());
        }

		redisTemplate.execute(new RedisCallback<Object>() {

			@Override
			public Object doInRedis(RedisConnection connection) throws DataAccessException {
				byte[] key = redisTemplate.getStringSerializer().serialize("AccessToken.id." + token.getId());
				byte[] value = redisTemplate.getStringSerializer().serialize(FlexJsonUtils.toJson(token));
				connection.set(key, value);
				connection.expire(key, token.getExpires_in());
				return null;
			}
		});
	}

	@Override
	public AccessToken findOne(final String id) {
		return redisTemplate.execute(new RedisCallback<AccessToken>() {
			@Override
			public AccessToken doInRedis(RedisConnection connection) throws DataAccessException {
				byte[] key = redisTemplate.getStringSerializer().serialize("AccessToken.id." + id);
				if (connection.exists(key)) {
					String value = redisTemplate.getStringSerializer().deserialize(connection.get(key));
					return FlexJsonUtils.fromJson(value, AccessToken.class);
				}
				return null;
			}
		});
	}

	@Override
	public void delete(final String id) {
		redisTemplate.execute(new RedisCallback<Object>() {

			@Override
			public Object doInRedis(RedisConnection connection) throws DataAccessException {
				byte[] key = redisTemplate.getStringSerializer().serialize("AccessToken.id." + id);
				connection.del(key);
				return null;
			}
		});
	}

}
