package com.uas.app.city.account.util;

import flexjson.JSONDeserializer;
import flexjson.JSONSerializer;
import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;

/**
 * Flex json serialize and deserialize class.
 *
 * @author huxz
 */
public class FlexJsonUtils {

    private static final int INITIAL_CAPACITY = 16;

    public static <T> T fromJson(String json, Class<T> cls) {
        return new JSONDeserializer<T>().use(null, cls).deserialize(json);
    }

    public static <K, V> Map<K, V> fromJson(String json) {
        Map<K, V> map = new HashMap<>(INITIAL_CAPACITY);
        return new JSONDeserializer<Map<K, V>>().use(null, map.getClass()).deserialize(json);
    }

    public static <K, V> LinkedHashMap<K, V> fromLinkedJson(String json) {
        Map<K, V> map = new LinkedHashMap<>();
        return new JSONDeserializer<LinkedHashMap<K, V>>().use(null, map.getClass())
                .deserialize(json);
    }

    public static String toJson(Object obj) {
        return new JSONSerializer().exclude("*.class").serialize(obj);
    }

    public static String toJsonDeep(Object obj) {
        return new JSONSerializer().exclude("*.class").deepSerialize(obj);
    }

    public static <T> String toJsonArray(Collection<?> collection) {
        return new JSONSerializer().exclude("*.class").serialize(collection);
    }

    public static <T> List<T> fromJsonArray(String json, Class<?> cls) {
        return new JSONDeserializer<List<T>>().use(null, ArrayList.class).use("values", cls)
                .deserialize(json);
    }

    public static <T> Map<String, T> fromJsonHashMap(String json, Class<?> cls) {
        return new JSONDeserializer<Map<String, T>>().use(null, HashMap.class).use("values", cls)
                .deserialize(json);
    }

    public String toJson() {
        return new JSONSerializer().exclude("*.class").serialize(this);
    }
}
