package com.uas.app.city.account.util.sso;

import com.uas.app.city.account.model.Company;
import com.uas.app.city.account.model.LocalUser;
import com.uas.app.city.account.model.UserView;
import com.uas.app.city.account.util.FlexJsonUtils;
import com.uas.sso.SSOToken;
import com.uas.sso.entity.UserAccount;
import org.apache.log4j.Logger;

/**
 * SSO access utils for authentication.
 *
 * @author huxz
 */
public class AccessUtils {

    public static final Logger logger = Logger.getLogger(AccessUtils.class);

    /**
     * 验证用户信息是否保存会话中，用户企业信息是否更新，或者会话中用户信息陈旧，
     * 如果是则更新会话中用户信息
     *
     * @param token     身份Token
     * @param cacheUser 会话缓存用户
     * @return  Boolean
     */
    public static boolean needUpdateUserSession(SSOToken token, LocalUser cacheUser) {
        if (logger.isDebugEnabled()) {
            logger.debug("Token data: " + token.getData());
        }

        if (cacheUser == null) {
            return true;
        }

        UserAccount userAccount = FlexJsonUtils.fromJson(token.getData(), UserAccount.class);
        UserView tokenUser = new UserView(userAccount);
        assert tokenUser != null;

        // 另一个用户登录了
        if (!tokenUser.getDialectUID().equals(cacheUser.getUserUu().toString())) {
            return true;
        }

        // 验证当前已登录企业用户是否切换企业，共享用户登录状态和信息
        Company enterprise = cacheUser.getEnterprise();
        if (enterprise != null && !enterprise.getBusinessCode().equals(tokenUser.getSpaceUID())) {
            if (logger.isDebugEnabled()) {
                logger.debug("当前企业用户已切换企业账套");
            }
            return true;
        }
        return false;
    }
}
