package com.uas.app.city.account.web;

import com.uas.app.city.account.model.City;
import com.uas.app.city.account.service.CityService;
import com.uas.app.city.account.support.ResultBean;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.data.web.PageableDefault;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

/**
 * Rest api for city operations.
 *
 * @author huxz
 */
@RestController
@RequestMapping(path = "/city")
public class CityController {

    private final CityService cityService;

    @Autowired
    public CityController(CityService cityService) {
        this.cityService = cityService;
    }

    @RequestMapping(method = RequestMethod.POST, path = "//insert-city-info",
            produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
    public ResultBean<City> insertCityInfoWhenAdminAdds(@RequestBody City city) {
        return new ResultBean<>(cityService.insertCityInfoWhenAdminAdds(city));
    }

    @RequestMapping(method = RequestMethod.PUT, path = "//edit-city-info",
            produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
    public ResultBean<City> updateCityInfoWhenAdminEdit(@RequestBody City city) {
        return new ResultBean<>(cityService.updateCityInfoWhenAdminEdit(city));
    }

    @RequestMapping(method = RequestMethod.DELETE, path = "//delete-city-info/{cityId}",
            produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
    public ResultBean<City> deleteCityInfoByAdmin(@PathVariable("cityId") Long cityId) {
        return new ResultBean<>(cityService.deleteCityInfoByAdmin(cityId));
    }

    @RequestMapping(method = RequestMethod.GET, path = "//page-city",
            produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
    public ResultBean<Page<City>> pageCityOnConditions(@PageableDefault Pageable pageable) {
        return new ResultBean<>(cityService.pageCityOnConditions(pageable));
    }

    @RequestMapping(method = RequestMethod.GET, path = "//find-city-list")
    public ResultBean<List<City>> findCityListOfOneUser() {
        return new ResultBean<>(cityService.findCityListOfOneUser());
    }
}
