package com.uas.app.city.account.web;

import com.mashape.unirest.http.exceptions.UnirestException;
import com.uas.app.city.account.dao.CityDao;
import com.uas.app.city.account.model.City;
import com.uas.app.city.account.third.model.AccessToken;
import com.uas.app.city.account.third.service.AccessTokenService;
import com.uas.app.city.account.util.ProxyUtils;
import javax.servlet.http.HttpServletRequest;
import org.apache.commons.lang3.Validate;
import org.apache.commons.lang3.math.NumberUtils;
import org.apache.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.MediaType;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

/**
 * Demo controller.
 *
 * @author huxz
 */
@RestController
@RequestMapping(path = "/api")
public class DemoController {

    private final Logger logger = Logger.getLogger(DemoController.class);

    private final CityDao cityDao;

    private final AccessTokenService accessTokenService;

    @Autowired
    public DemoController(CityDao cityDao,
            AccessTokenService accessTokenService) {
        this.cityDao = cityDao;
        this.accessTokenService = accessTokenService;
    }

    @RequestMapping(method = RequestMethod.GET, path = "/demo", produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
    public ModelMap test() {
        ModelMap modelMap = new ModelMap();
        modelMap.addAttribute("name", "White");
        modelMap.addAttribute("age", 12);
        return modelMap;
    }

    @RequestMapping(path = "/serve/uploadAttach.action", produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
    public String proxyUploadFiles(HttpServletRequest request, String cityId) throws UnirestException {
        if (logger.isDebugEnabled()) {
            logger.debug("Proxy url: " + request.getRequestURI() + "?" + request.getQueryString());
        }
        Validate.notNull(cityId, "当前产城ID必须指定");

        return "{}";
    }

    @RequestMapping(path = "/serve/mainPage/**/*.action", produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
    public String proxyCommonRequest(HttpServletRequest request, String cityId) throws UnirestException {
        if (logger.isDebugEnabled()) {
            logger.debug("Proxy url: " + request.getRequestURI() + "?" + request.getQueryString());
        }
        Validate.notNull(cityId, "当前产城ID必须指定");

        City city = cityDao.findOne(NumberUtils.toLong(cityId));

        final String baseUrl = city.getAdminSite();

        if (logger.isDebugEnabled()) {
            logger.debug("Admin site: " + baseUrl);
        }

        return ProxyUtils.proxyCommonRequest(request, baseUrl);
    }

    @RequestMapping(path = "/serve/**/*.action", produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
    public String proxy(HttpServletRequest request, String cityId) throws UnirestException {
        if (logger.isDebugEnabled()) {
            logger.debug("Proxy url: " + request.getRequestURI() + "?" + request.getQueryString());
        }
        Validate.notNull(cityId, "当前产城ID必须指定");

        AccessToken accessToken = accessTokenService.createNew("10046669");

        City city = cityDao.findOne(NumberUtils.toLong(cityId));

        final String baseUrl = city.getAdminSite();

        if (logger.isDebugEnabled()) {
            logger.debug("Admin site: " + baseUrl);
        }

        return ProxyUtils.proxyRequest(request, baseUrl, accessToken);
    }

}
