package com.uas.app.city.account.web;

import com.alibaba.fastjson.JSON;
import com.uas.app.city.account.model.LocalUser;
import com.uas.app.city.account.model.UserView;
import com.uas.app.city.account.service.LocalUserService;
import com.uas.app.city.account.support.SystemSession;
import com.uas.app.city.account.util.FlexJsonUtils;
import com.uas.sso.AuthToken;
import com.uas.sso.SSOConfig;
import com.uas.sso.SSOHelper;
import com.uas.sso.SSOToken;
import com.uas.sso.entity.UserAccount;
import org.apache.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import java.io.IOException;

/**
 * An controller implementations to login and logout.
 *
 * @author huxz
 */
@Controller
public class LoginController {

    private final Logger logger = Logger.getLogger(LoginController.class);

    private final LocalUserService userService;

    @Autowired
    public LoginController(LocalUserService userService) {
        this.userService = userService;
    }

    /**
     * 获取账户中心注册页面url.
     */
    @RequestMapping(method = RequestMethod.GET, path = "/register/page")
    @ResponseBody
    public ModelMap register(HttpServletRequest request, HttpServletResponse response,
            String returnUrl) throws IOException {
        if (logger.isDebugEnabled()) {
            logger.debug("User plans to register");
        }

        request.getSession().setAttribute(SSOConfig.SSOReferer, returnUrl);
        SSOHelper.clearLogin(request, response);

        String redirectUrl;
        if (StringUtils.isEmpty(returnUrl)) {
            redirectUrl = SSOHelper.getRedirectRefererRegisterUrl(request);
        } else {
            redirectUrl = SSOHelper.getRedirectRegisterUrl(request, returnUrl);
        }
        return new ModelMap("content", redirectUrl);
    }

    /**
     * 旧版获取跳转登录的url.
     */
    @RequestMapping(method = RequestMethod.GET, path = "/login/old-page")
    @ResponseBody
    public ModelMap loginOldPage(HttpServletRequest request, HttpServletResponse response,
            String returnUrl) throws IOException {
        if (logger.isDebugEnabled()) {
            logger.debug("User plans to login");
        }

        request.getSession().setAttribute(SSOConfig.SSOReferer, returnUrl);
        SSOHelper.clearLogin(request, response);

        String redirectUrl;
        if (StringUtils.isEmpty(returnUrl)) {
            redirectUrl = SSOHelper.getRedirectRefererLoginUrl(request);
        } else {
            redirectUrl = SSOHelper.getRedirectLoginUrl(request, returnUrl);
        }

        boolean cross = SSOHelper.isCrossDomain(request);
        if (cross) {
            // 跨域代理界面
            redirectUrl = request.getContextPath() + "/login/proxy";
        }
        return new ModelMap("content", redirectUrl);
    }

    /**
     * 获取跳转登录的url.
     */
    @RequestMapping(method = RequestMethod.GET, path = "/login/page")
    @ResponseBody
    public ModelMap login(HttpServletRequest request, HttpServletResponse response,
            String returnUrl) throws IOException {
        if (logger.isDebugEnabled()) {
            logger.debug("User plans to login");
        }

        request.getSession().setAttribute(SSOConfig.SSOReferer, returnUrl);
        SSOHelper.clearLogin(request, response);

        String redirectUrl;
        if (StringUtils.isEmpty(returnUrl)) {
            redirectUrl = SSOHelper.getRedirectRefererLoginUrl(request);
        } else {
            redirectUrl = SSOHelper.getRedirectLoginUrl(request, returnUrl);
        }

        ModelMap map = new ModelMap("content", redirectUrl);
        map.put("baseUrl","/login/other");
        return map;
    }

    /**
     * 其他地点登录后 同步登录状态
     * @param request
     * @param response
     */
    @RequestMapping(value = "/login/other", produces = {"application/javascript"})
    @ResponseBody
    public String afterCrossLogin(HttpServletRequest request, HttpServletResponse response, UserAccount userAccount, Integer maxage) {

        if (userAccount != null && userAccount.getMobile() != null) {
            SSOToken token = new SSOToken();
            token.setUid(userAccount.getMobile());
            token.setTime(System.currentTimeMillis());
            token.setData(JSON.toJSONString(userAccount));
            if (null != maxage) {
                request.setAttribute("sso_cookie_maxage", maxage);
            }
            SSOHelper.setSSOCookie(request, response, token, true);
            response.setHeader("P3P","CP='IDCDSP COR ADM DEVi TAIi PSA PSD IVAi IVDi CONi HIS OUR IND CNT'");

            response.setHeader("P3P","CP=\"CURaADMa DEVa PSAo PSDo OUR BUS UNI PUR INT DEM STA PRE COM NAV OTC NOI DSPCOR\"");
            UserView userView = new UserView(getUserByToken(token));
            LocalUser localUser = userService.findUserInfoByToken(token, "5");
            if (userView != null) {
                request.getSession().setAttribute("user", localUser);
                SystemSession.setUser(localUser);
            }
            return "successCallback({success:'1'})";
        }
        return "successCallback({success:'0'})";
    }

    private UserAccount getUserByToken(SSOToken token) {
        UserAccount authedUser = null;
        if (token.getData() != null) {
            UserAccount tokenUser = FlexJsonUtils.fromJson(token.getData(), UserAccount.class);
            authedUser = tokenUser;
//            if (tokenUser.getUid() != null) {
//                // UID表示所有系统公认的唯一标识，这里统一使用手机号
//                authedUser = userService.findUserByUserTel(tokenUser.getUid());
//            } else if (tokenUser.getDialectUID() != null) {
//                // dialectUID表示client系统自己的唯一标识，比如user_uu，手机号没设置的情况下使用
//                authedUser = userService.findUserByUserUU(Long.parseLong(tokenUser.getDialectUID()));
//            } else {
//                logger.error(String.format("invalid user %s, please set uid or dialectUID", tokenUser.getName()));
//            }
        }
        return authedUser;
    }

    /**
     * 获取跨域登录的参数.
     */
    @RequestMapping(value = "/login/crossBefore")
    @ResponseBody
    public ModelMap getCrossLoginData(HttpServletRequest request, HttpServletResponse response)
            throws IOException {
        ModelMap model = new ModelMap();
        SSOConfig config = SSOHelper.getSSOService().getConfig();
        // 业务系统私钥签名 authToken 自动设置临时会话 cookie 授权后自动销毁
        AuthToken token = SSOHelper.askCiphertext(request, response, config.getClientPrivateKey());
        // askUrl 询问 sso 是否登录地址
        model.addAttribute("askUrl", config.getCrossAskUrl());
        // askTxt 询问 token 密文
        model.addAttribute("askData", token.encryptAuthToken());
        // 未登录情况下，登录地址
        Object loginUrl;
        boolean cross = SSOHelper.isCrossDomain(request);
        if (cross) {
            loginUrl = SSOHelper.getRedirectRefererLoginUrl(request);
        } else {
            loginUrl = SSOHelper.getRedirectLoginUrl(request,
                    String.valueOf(request.getSession().getAttribute("SSOReferer")));
        }
        model.addAttribute("loginUrl", loginUrl + "&domain=" + "thxz");

        if (logger.isDebugEnabled()) {
            logger.debug(model);
        }
        return model;
    }

    /**
     * 跨域登录后.
     */
    @RequestMapping(value = "/login/crossAfter")
    @ResponseBody
    public ModelMap afterCrossLogin(HttpServletRequest request, HttpServletResponse response,
            String replyTxt) {
        if (!StringUtils.isEmpty(replyTxt)) {
            Object returnUrl = request.getSession().getAttribute(SSOConfig.SSOReferer);
            SSOConfig config = SSOHelper.getSSOService().getConfig();
            AuthToken token = SSOHelper.ok(request, response, replyTxt, config.getClientPublicKey(),
                    config.getCenterPublicKey());
            if (token != null) {
                SSOToken tk = new SSOToken();
                tk.setUid(token.getUid());
                tk.setTime(token.getTime());
                tk.setData(token.getData());
                SSOHelper.setSSOCookie(request, response, tk, true);

                returnUrl = returnUrl.toString().contains("10.10.0.10") ? "/" : returnUrl;
                return new ModelMap("returnUrl", returnUrl);
            }
        }
        return null;
    }

    /**
     * 获取跨域注销的参数.
     */
    @RequestMapping(value = "/logout/crossBefore")
    @ResponseBody
    public ModelMap getCrossLogoutData(HttpServletRequest request, HttpServletResponse response)
            throws IOException {
        SSOHelper.clearLogin(request, response);
        ModelMap model = new ModelMap();
        SSOConfig config = SSOHelper.getSSOService().getConfig();
        model.addAttribute("askUrl", config.getCrossAskOutUrl());
        Object referer = request.getSession().getAttribute(SSOConfig.SSOReferer);
        model.addAttribute("returnUrl", null == referer ? "/" : referer.toString());
        // 未登录情况下，登录地址
        Object logoutUrl;
        boolean cross = SSOHelper.isCrossDomain(request);
        if (cross) {
            logoutUrl = SSOHelper.getRedirectRefererLogoutUrl(request);
        } else {
            logoutUrl = SSOHelper.getRedirectLogoutUrl(request, String.valueOf(request.getSession().getAttribute("SSOReferer")));
        }
        model.addAttribute("logoutUrl", logoutUrl);
        model.addAttribute("baseUrl","/logout");

        // 清除系统用户会话信息
        request.getSession().invalidate();
        return model;
    }

    /**
     * 退出登录
     * @param request
     * @param response
     * @param session
     * @param returnUrl 退出之后要跳转的路径
     * @return
     * @throws IOException
     */
    @RequestMapping(value = "/logout", method = RequestMethod.GET, headers = "Accept=application/json")
    @ResponseStatus(value = HttpStatus.OK)
    @ResponseBody
    public String logout(HttpServletRequest request, HttpServletResponse response, HttpSession session, String returnUrl)
            throws IOException {
        String callback =request.getParameter("jsoncallback");
        response.setContentType("text/html;charset=UTF-8");
        session.invalidate();
        SSOHelper.clearLogin(request, response);
        SystemSession.clear();
        if (org.apache.commons.lang3.StringUtils.isEmpty(returnUrl)) {
            returnUrl = request.getHeader("Referer");
        }
        return "successCallback({success:'1'})";
    }
}
