package com.uas.app.city.account.web;

import com.uas.app.city.account.model.Company;
import com.uas.app.city.account.model.LocalUser;
import com.uas.app.city.account.service.CompanyService;
import com.uas.app.city.account.service.LocalUserService;
import com.uas.app.city.account.service.SyncService;
import com.uas.sso.entity.UserSpaceView;
import com.uas.sso.entity.UserView;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.Date;
import java.util.Iterator;
import java.util.Set;

/**
 * 同步账户中心数据
 *
 * @author liuam
 * @date 2018/6/7 0007 下午 14:43
 */
@RestController
@RequestMapping("/sync")
public class SyncController {

    @Autowired
    private SyncService syncService;

    @Autowired
    private CompanyService companyService;

    @Autowired
    private LocalUserService localUserService;

    /**
     * 同步企业数据接口
     * @param userSpaceView
     * @param userView
     * @return 保存后的 user And company
     */
    @PostMapping("/enterprise")
    public void syncEnterprise (UserSpaceView userSpaceView, UserView userView) {
        Company company = companyService.getCompanyBySpaceUU(userSpaceView.getSpaceUU());
        LocalUser localUser = localUserService.findByUserUu(userView.getUserUU());
        if (company == null) {
            // 构造company
            Company cp = new Company();
            cp.setTelephone(userSpaceView.getTelephone());
            cp.setRegDate(new Date(userSpaceView.getRegisterDate()));
            cp.setName(userSpaceView.getSpaceName());
            cp.setBusinessCode(userSpaceView.getBusinessCode());
            cp.setSpaceUU(userSpaceView.getSpaceUU());
            company = cp;
        }

        if (localUser == null) {
            LocalUser lu = new LocalUser();
            lu.setUserUu(userView.getUserUU());
            localUser = lu;
        }
        localUser.getEnterprises().add(company);
        syncService.saveUserAndCompany(localUser, company);
    }

    /**
     * 同步用户数据接口
     * @param userView
     * @return 保存后的 user
     */
    @PostMapping("/user")
    public void syncUser (UserView userView) {
        LocalUser localUser = new LocalUser();
        localUser.setUserUu(userView.getUserUU());
        LocalUser user = localUserService.save(localUser);
    }

    /**
     * 同步用户绑定企业
     * @param spaceUU
     * @param userUU
     * @param type
     * @return 保存后的 user And company
     */
    @PostMapping("/bind")
    public void bind (Long spaceUU, Long userUU, String type) {

        Company company = companyService.getCompanyBySpaceUU(spaceUU);
        LocalUser localUser = localUserService.findByUserUu(userUU);

        if (company == null || localUser == null) {
            return ;
        }

        if ("bind".equals(type)) {
            localUser.getEnterprises().add(company);
            syncService.saveUserAndCompany(localUser, company);
            return ;
        }
        if ("unbind".equals(type)) {
            Set<Company> companies = localUser.getEnterprises();
            Iterator<Company> iterator = companies.iterator();
            while (iterator.hasNext()) {
                Company company1 = iterator.next();
                if (company1.getSpaceUU().equals(spaceUU)) {
                    iterator.remove();
                }
            }
            localUser.setEnterprises(companies);
            syncService.saveUserAndCompany(localUser, company);
        }
    }

}
